/* HiURLBoard */

#import <Cocoa/Cocoa.h>

#define ITEMID_NAME		@"name"
#define ITEMID_NOTE	@"notes"
#define DUMMY_EXTENSION	@"file"
#define NAMEID_CHAR		@":"		//グループ名と区別するためURLデータ名の最後に付け加える文字
//#define REPLACE_COLON	@"_"		//ファイル名のコロンの変わりに置き換えられる文字
#define ROOTDIR_NAME	@"_root"
#define DUMMYURL_NAME	@"_dummy"

#define MoveInGroup_Bit	1
#define DirectionUp_Bit	2
#define RenameError_Bit	4
#define DeleteError_Bit	8

#define DEF_AutoExpandable	NO
#define KEY_AutoExpandable	@"AutoExpandableItemMode"
#define DEF_UniqueNameNumber	0
#define KEY_UniqueNameNumber	@"UniqueNameNumber"

#define	Key_URLBoardColumnWidths	@"URLBoardColumnWidths"

@class HiWeblocFile;
@class HiURLEditor;
@class HiURLOffice;
@class HiOutlineView;
@class HiGroupEditor;
@class HiHTMLReader;
@class HiColorLabel;

@interface HiURLBoard : NSObject	<NSOutlineViewDataSource>
{
	HiWeblocFile	*webloc;
	HiOutlineView	*dataView;		//情報資源表示ビュー
	HiURLEditor		*urlEditor;
	HiURLOffice		*office;
	HiGroupEditor	*groupEditor;
	HiHTMLReader	*htmlReader;
	HiColorLabel	*labeler;
	
	NSWindow		*mainWindow;
	id	progressField;				//処理中のアイテム数を表示する
	
	NSMutableArray	*list;			//アイテム一覧
	BOOL			outsideDrop;	//アイテム以外の場所にドロップされた
	int				nameNumber;		//名前識別のための番号
	NSMutableArray	*draggedPathList;	//ドラッグされたアイテムのパスリスト
	BOOL			operationCopy;	//ドラッグは移動
	BOOL			dragging;		//現在ドラッグ中
	BOOL			autoExpand;		//自動展開フラグ
	int				moveFromPoint;	//ドラッグ時の移動元行
}

//********************
// 初期化等
//********************

- (void)saveLastNameNumber;
- (void)saveLastList;	//現在の一覧表を保存する
- (void)dealloc;


//********************
// アクセッサ
//********************

- (BOOL)autoExpand;
- (void)setAutoExpand:(BOOL)inBool;
- (void)setDragging:(BOOL)inBool;
- (int)moveFromPoint;
- (NSMutableArray *)list;

//**************************
// ユーティリティ
//**************************

//アイテム関係
- (BOOL)isGroupItem:(NSArray *)item;
- (void)removeAbsentItemWithList:(NSMutableArray *)inList
					  countGroup:(int *)countGroup
					   countItem:(int *)countItem;	//一覧表のデータを修正する（削除）
- (void)appendItemListWithPath:(id)inPath
					countGroup:(int *)countGroup
					 countItem:(int *)countItem;	//一覧表のデータを修正する（追加）
- (id)filePathOfURLItem:(id)item;	//itemを含むデータフォルダからのファイルパス
- (id)filePathWithGroup:(NSArray *)group itemName:(id)itemName;	//groupグループ内を階層的に検索してitemNameアイテムのパスを得る

//グループアイテム関係
- (BOOL)isGroupName:(id)name;	//*****name名前がグループ名かどうかを調べる

//ＵＲＬアイテム関係
- (BOOL)isURLItemName:(id)name;	//nameがＵＲＬアイテム名かどうかを調べる

//一覧表関係
- (void)setListWithPath:(id)inPath;		//一覧表のデータを作り直しする
- (void)reviceListWithPath:(id)inPath;	//一覧表のデータを修正する
- (void)loadListWithPath:(id)inPath;	//前回の一覧表をセットする・なければ作り直しする
- (BOOL)isListExistWithPath:(id)inPath;
- (void)saveListWithPath:(id)inPath;	//現在の一覧表を保存する
- (NSMutableArray *)mutableListWithInmutableList:(NSArray *)inList;	//すべてのNSArrayをNSMutableArrayに変更する
- (NSArray *)rootGroupList;	//ルートにあるすべてのグループ名を得る

//ドラッグ＆ドロップ
- (BOOL)checkPathList:(NSArray *)pathList;
- (BOOL)outsideDrop;
- (id)titleNameWithURLString:(id)urlString;
- (void)selectDroppedPointWithItem:(id)item atIndex:(int)index;
- (int)rowForRootIndex:(int)index;
- (BOOL)isDescendant:(id)childItem parent:(id)parentItem;
- (BOOL)isOperationCopy;	//ドラッグ操作は移動かどうか

//その他
- (id)uniqueNameNumber;	//ディレクトリ名と区別するための名前識別子
- (id)fastUniqueNameNumber;	//ディレクトリ名と区別するための名前識別子（ファイルに保存しないので早い）
- (BOOL)isItemExistInList:(id)inName
				   folder:(BOOL)folder;	//listの中のinNameアイテムの存在を調べる,folderはフォルダかファイルかの判別フラグ
- (BOOL)isItemExistInListSub:(id)inName
						list:(NSArray *)inList
					  folder:(BOOL)folder;	//isItemExistInListの再帰的に呼ばれる部分
- (NSMutableArray *)groupListOfItemPath:(id)itemPath;	//itemPathのデータフォルダから最後のアイテムまでのグループリスト
- (BOOL)insertWeblocFile:(id)itemName
					 url:(id)urlData
			  parentItem:(id)item
			   dropPoint:(int)index;	//Weblocファイルを作成,一覧表に挿入し、表示を更新して終了
- (BOOL)insertWeblocFile:(id)itemName
					 url:(id)urlData
			  parentItem:(id)item
			   dropPoint:(int)index
				   watch:(BOOL)watch;	//Weblocファイルを作成,一覧表に挿入し、表示を更新して終了
//- (NSString *)reviceDotFileName:(NSString *)name;		//名前の先頭に"."が使われているなら全角の"․"に入れ替える


//**************************
// NSOutlineView内部使用メソッド
//**************************

- (NSMutableArray *)itemAtGroupList:(NSMutableArray *)group
							   name:(id)name;	//ルートから階層的に検索してgroupグループ内のnameアイテムを得る
- (NSMutableArray *)itemInGroup:(NSMutableArray *)group	//*****
						   name:(id)name;	//groupグループ内を階層的に検索し名前がnameのグループまたはアイテムを得る
- (NSMutableArray *)groupInGroup:(NSMutableArray *)group
							name:(id)name;	//groupグループ内の名前がnameのグループ
- (id)itemNameAt:(int)index
		   group:(id)group;	//groupグループ内のindex番目のアイテムの名前、group=nilはルートグループ
- (id)nameOfItem:(NSArray *)item;	//itemアイテムの名前
- (id)noteOfItem:(NSArray *)item;	//itemアイテムの備考文字を得る
- (int)itemCountOfGroup:(id)group;	//groupグループ内のアイテムの個数
- (int)itemCountWithinRoot;
- (int)itemCountWithinGroup:(id)group	//*****
					atGroup:(NSArray *)atGroup;	//グループ内すべてのアイテムの個数
- (int)groupCountWithinRoot;
- (int)groupCountOfGroup:(id)group;	//グループ内のグループアイテムの数
- (int)groupCountWithinGroup:(id)group	//*****
					 atGroup:(NSArray *)atGroup;	//グループ内すべてのグループの個数
- (void)setObjectOfItem:(NSArray *)item
				 object:(id)object
			 identifier:(id)identifier;
- (void)sortListWithDescriptors:(NSArray *)sortDescriptors;
- (NSString *)groupNoteWithItem:(NSString *)item;
- (NSString *)itemNoteWithItem:(NSString *)item;

//- (id)noteOfGroupItem:(id)item;
//- (int)itemCountOfRoot;	//ルートのアイテムの個数
//- (id)objectOfItem:(id)item
//				identifier:(id)identifier;	//itemアイテム内の識別文字identifierを持つアイテム

//**************************
// NSOutlineViewに必要なメソッド
//**************************

//itemのchild数を返す、itemがnilならrootのchild数
- (int)outlineView:(NSOutlineView *)outlineView
numberOfChildrenOfItem:(id)item;

//itemグループのchild番目のアイテムを返す、itemがnilならrootのchild item を返す
- (id)outlineView:(NSOutlineView *)outlineView
			child:(int)index
		   ofItem:(id)item;
		   
//itemがグループ名ならYES、ＵＲＬデータならNOを返す
- (BOOL)outlineView:(NSOutlineView *)outlineView
   isItemExpandable:(id)item;
   
//itemアイテム内のtableColumnのidentifierのアイテムを返す
- (id)outlineView:(NSOutlineView *)outlineView
	objectValueForTableColumn:(NSTableColumn *)tableColumn
					   byItem:(id)item;

//********************************
// 表示幅を記録するのに必要なデリゲート
//********************************

- (void)outlineViewColumnDidResize:(NSNotification *)notification;

//********************************
// ソートに必要なメソッド（デリゲート）
//********************************

//列のヘッダをクリックするとここに来る
- (void)outlineView:(NSOutlineView *)tableView
sortDescriptorsDidChange:(NSArray *)oldDescriptors;	//列のヘッダをクリックするとここに来る

					   
//******************************
// ドラッグ＆ドロップに必要なメソッド
// (デリゲート)
//******************************

//===============================
//内部のアイテムのドラッグが開始された
//===============================
- (BOOL)outlineView:(NSOutlineView *)outlineView
		 writeItems:(NSArray *)items
	   toPasteboard:(NSPasteboard *)pboard;

//========================
//アイテムがドラッグされてきた
//========================
- (NSDragOperation)outlineView:(NSOutlineView *)outlineView
				  validateDrop:(id <NSDraggingInfo>)info
				  proposedItem:(id)item
			proposedChildIndex:(int)index;

//=====================
//アイテムがドロップされた
//=====================
- (BOOL)outlineView:(NSOutlineView *)outlineView
		 acceptDrop:(id <NSDraggingInfo>)info
			   item:(id)item
		 childIndex:(int)index;
- (BOOL)isApplication:(NSString *)path;
- (BOOL)isFolderPath:(NSString *)path;
- (BOOL)folderDropped:(id <NSDraggingInfo>)info
				 item:(id)item
		   childIndex:(int)index
			optionKey:(BOOL)optionKey;
- (BOOL)createNewGroupWithItem:(id)item
					  itemName:(NSString *)itemName
						 atIndex:(int)index;
- (BOOL)makeUrlFile:(id )name
				url:(id )url;	//新規のファイル名でWindows形式のurlファイルを作成

//***********************************
// AutosaveExpandedItems に必要なメソッド
//***********************************

- (id)outlineView:(NSOutlineView *)outlineView
	itemForPersistentObject:(id)object;

- (id)outlineView:(NSOutlineView *)outlineView
	persistentObjectForItem:(id)item;

//***********************************
// 自動展開をコントロールするのに必要なメソッド
//***********************************

- (BOOL)outlineView:(NSOutlineView *)outlineView
   shouldExpandItem:(id)item;	//グループアイテムの自動展開をコントロール

//***********************************
// カラーラベル表示するのに必要なメソッド
// 空のグループ表示
//***********************************

- (void)outlineView:(NSOutlineView *)outlineView
	willDisplayCell:(id)cell
	 forTableColumn:(NSTableColumn *)tableColumn
			   item:(id)item;	//テーブルのセルを描く前に呼ばれる

//***********************************
// toolTipを表示するのに必要なメソッド
//***********************************

- (NSString *)outlineView:(NSOutlineView *)ov
		   toolTipForCell:(NSCell *)cell
					 rect:(NSRectPointer)rect
			  tableColumn:(NSTableColumn *)tc
					 item:(id)item
			mouseLocation:(NSPoint)mouseLocation;


//********************
// 実行状況表示関係
//********************

//- (void)startProgress:(NSString *)message;
/*
 - (void)sheetDidEnd:(NSWindow *)sheet
		 returnCode:(int)returnCode
		contextInfo:(void *)contextInfo;
*/
//- (void)stopProgress;

@end
