/* HiURLEditor */

#import <Cocoa/Cocoa.h>

#define NewURL_Mode		1
#define DropURL_Mode	2
#define EditURL_Mode	3

enum {
	kNoChangeIcon	= 0,
	kDefaultIcon	= 1,
	kCustomIcon		= 2
};

@class HiURLOffice;
@class HiWeblocFile;
@class HiURLBoard;
@class HiPreferences;
@class HiColorLabel;

#define	kTempFilePath		@"/.TempFile.tmp"

@interface HiURLEditor : NSObject
{
	HiURLOffice		*office;
	HiWeblocFile	*webloc;
	HiURLBoard		*board;
	HiPreferences	*prefs;
	HiColorLabel	*labeler;
	IBOutlet id		watcher;
	
	NSPanel			*editPanel;
	NSTextField		*nameText;
	NSTextField		*urlText;
	NSButton		*executeButton;
	NSButton		*cancelButton;
	NSOutlineView	*dataView;
	NSWindow		*mainWindow;
	NSTextField		*browserText;
	NSButton		*selectButton;
	NSButton		*clearButton;
	NSColorWell		*colorWell;
//	NSImageView		*iconImageView;
	NSButton		*iconImageButton;
	NSButton		*watchSwitchCheck;
	//-------------------------------v181
	id				selectFileButton;
	//-----------------------------------
	
	NSColor			*textColor;
	BOOL			editURLMode;
	NSString		*parentGroup;
	int				dropPoint;
	NSString		*originalURL;
	NSImage			*defaultIconImage;
	NSImage			*customIconImage;
	int				isChangedIcon;
	BOOL			watchSwitch;
}

//********************
// 初期化等
//********************

- (void)awakeFromNib;
- (void)dealloc;


//********************
// アクション等
//********************

- (void)editNewURLWithName:(NSString *)urlName
					   url:(NSString *)urlData
				parentGroup:(NSString *)group
				 dropPoint:(int)index;//プログラム（ファイルドロップ時）から呼ばれる、名前編集のみの実行
- (void)actEditNewURL:(id)sender;	//メニュー（新規作成）から呼ばれる
- (void)actEditURLData:(id)sender;	//メニュー（情報資源の編集）から呼ばれる
- (void)actExecute:(id)sender;	//実行ボタンが押された
- (void)actCancel:(id)sender;
- (void)actSelectBrowser:(id)sender;
- (void)actDefaultBrowser:(id)sender;
- (void)actColorWell:(id)sender;
- (void)actIconImageButton:(id)sender;
- (void)actURLText:(id)sender;
//-------------------------------v181
- (void)actSelectFile:(id)sender;
//-----------------------------------


//********************
// ユーティリティ
//********************

- (void)editStart;			//新規、編集ともに最終的にここへくる
- (void)executeNewURL;		//メニューで新規のＵＲＬデータを作成
- (void)executeDropURL;		//Ｄ＆Ｄで新規のＵＲＬデータを作成
- (void)executeChangeURL;	//ＵＲＬデータを変更
- (void)executeEnd;
- (void)editEnd;			//すべての作業終了時にここへ来る
- (void)urlTextEnabled:(BOOL)inBool;
- (int)createNewURLItem:(NSString *)urlName
					 url:(NSString *)urlData
				  watch:(BOOL)watch;	//URLデータを作成し現在の選択位置に挿入する
- (int)dispErrorAlert:(int)error;
- (BOOL)changeURLName:(NSString *)urlName;	//URL名（ファイル、一覧表）の変更
- (void)replaceURLNameAtGroup:(NSMutableArray *)groupList
						oldName:(NSString *)oldName
						newName:(NSString *)newName;	//指定のＵＲＬ名を変更する
- (void)insertEmptyItemWithGroup:(NSMutableArray *)group
					 pointItem:(NSString *)pointItem
					insertItem:(NSString *)insertItem;	//insertItemをgroupグループ内のpointItemの前に挿入する
- (void)appendEmptyItemWithGroup:(NSMutableArray *)group
					  insertItem:(NSString *)insertItem;	//insertItemをgroupグループ内の最後尾に追加する

- (BOOL)isSameColor:(NSColor *)colorA and:(NSColor *)colorB;
- (void)selectBrowserEnabled:(BOOL)inBool;

- (NSString *)uniqueItemName:(NSString *)inName;	//名前の末尾が番号なら番号を＋１する、番号でなければ＿２を追加する
- (void)windowWillClose:(NSNotification *)aNotification;

@end
