/* HiURLOffice */

#import <Cocoa/Cocoa.h>

#define COLUMN_NAME		0
#define COLUMN_NOTES	1
#define ALREADCHECK_FILE	@".ForbiddenCharacterAlreadyChecked"
#define kTryGetFaviconMax	1

#define	EDITNOTE_ITEMTAG		1
#define EDITGROUP_ITEMTAG		2
#define EDITURL_ITEMTAG			3
#define GETFAVICON_ITEMTAG		4
#define CREATEWINURL_ITEMTAG	5
#define DELETEITEM_ITEMTAG		6
#define DUPLICATE_ITEMTAG		7
#define	EDITICON_ITEMTAG		8
#define	HISTORY_ITEMTAG			9
#define	CLEARHISTORY_ITEMTAG	10
#define	WatchNow_ITEMTAG		11
#define	Renewaled_ItemTag		12
#define	WatchList_ItemTag		13
#define	RenewaledSub_ItemTag	14
#define	SelectFolder_ItemTag	15
#define	CopyFavicon_ItemTag		16
#define	OpenClose_ItemTag		17
#define	EditNameOrData_ItemTag	20
#define	CopyName_ItemTag		21

//情報資源の削除確認関係
#define	DeleteMode_Cancel		0
#define	DeleteMode_Delete		1
#define	DeleteMode_Original		-1

//スタートアップアニメーション関係
#define	kStartupAnimationInitSize	32
#define	kStartupAnimationMaxSize	256
#define kStartupAnimationSteps		(kStartupAnimationMaxSize / kStartupAnimationInitSize)
#define	kStartupAnimationFraction	0.5f

enum {
	HiError_NoError		= 0,
	HiError_FileDuplicate		= -1,
	HiError_NoFileCleate		= -2,
	HiError_NoFileInsert		= -3,
	HiError_NoFileExist			= -4,
	HiError_NoFileWrite			= -5,
	HiError_EmptyURLTitle		= -6
};

#define DEF_DataFolder			@"~/Documents/HiURLCenterData"
#define KEY_DataFolder			@"DataFolder"
#define DEF_IndentWidth			16.0f
#define KEY_IndentWidth			@"IndentationWidth"
#define DEF_FolderCollection	[NSMutableArray arrayWithCapacity:0]
#define KEY_FolderCollection	@"FolderCollection"
#define DEF_MaxFolderItems		20
#define KEY_MaxFolderItems		@"MaximumFolderItems"
#define KEY_AUTOSAVE			@"NSOutlineView Items"
#define KEY_LASTSELECT			@"LastSelectOf"
#define KEY_LASTLIST			@"LastListOf"
#define DEF_RenewListAtAwake	NO
#define KEY_RenewListAtAwake	@"RenewListAtAwakeFlag"
#define Def_NameColumnWidth		175.0
#define Key_NameColumnWidth		@"NameColumnWidth"
#define Def_NoteColumnWidth		96.0
#define Key_NoteColumnWidth		@"NoteColumnWidth"
#define Def_WatchSeconds		30.0
#define Key_WatchSeconds		@"EstablishLANWatchSeconds"
#define Def_DelaySeconds		5.0
#define Key_DelaySeconds		@"AccessLANDelaySeconds"
#define DEF_DefaultBrowser		@""
#define KEY_DefaultBrowser		@"DefaultBrowserApplication"
#define DEF_FileBrowser			@""
#define KEY_FileBrowser			@"FileBrowserApplication"
//-------------------------------------------------------v180
#define DEF_FileEditor			@""
#define KEY_FileEditor			@"FileEditorApplication"
#define	DEF_PDFReader			@""
#define	KEY_PDFReader			@"PDFReaderApplication"
#define	DEF_DocEditor			@""
#define	KEY_DocEditor			@"DocumentEditorApplication"
#define	DEF_DocsetReader		@""
#define	KEY_DocsetReader		@"DocumentsetReaderApplication"
//-------------------------------------------------------v180
#define	DEF_PictureBrowser		@""
#define	KEY_PictureBrowser		@"PictureBrowserApplication"
#define	DEF_MoviePlayer			@""
#define	KEY_MoviePlayer			@"MoviePlayerApplication"
#define	DEF_SoundPlayer			@""
#define	KEY_SoundPlayer			@"SoundPlayerApplication"
//-----------------------------------------------------------
#define	Def_SelectExecMax		10				//選択して実行時の最大実行項目数
#define	Key_SelectExecMax		@"SelectExecMax"

@class HiURLCenter;
@class HiURLBoard;
@class HiWeblocFile;
@class HiOutlineView;
@class HiGroupEditor;
@class HiNoteEditor;
@class HiURLEditor;
@class HiHTMLMaker;
@class HiCommenter;

@interface HiURLOffice : NSObject
{
	HiOutlineView	*dataView;		//情報資源表示ビュー
	HiWeblocFile	*webloc;
	HiURLBoard		*board;	//URLショートカットの一覧
	HiCommenter		*commenter;
	IBOutlet id		utility;
	IBOutlet id		watcher;
	IBOutlet id		center;
	
	NSTextField		*urlText;		//URL表示用
	NSTextField		*timesText;		//アクセス回数表示用
	NSTextField		*dateText;		//前回アクセス表示用
	NSButton		*watchCheck;	//更新の有無表示用
	NSTextField		*itemCountText;	//アイテム数表示用
	NSPanel			*inspectPanel;					//データフォルダ変更中の表示パネル
	NSTextField		*folderText;			//データフォルダ変更中の状況表示テキスト
	NSProgressIndicator	*folderIndicator;	//データフォルダ変更中のプログレスインジケータ
	NSTextField		*pathText;
	NSWindow		*mainWindow;
	NSButton		*switchStateButton;	//グループを開閉ボタン
	NSButton		*browserButton;			//ブラウザ名表示ボタン
	NSPanel			*mountPanel;			//ネットボリュームのマウント・アンマウント表示用
	NSTextField		*mountText;
	NSPanel			*progressPanel;			//faviconデータ再取得中のシート表示用
	NSTextField		*progressText;			//faviconデータ再取得中のシート表示用
	NSProgressIndicator	*progressIndicator;	//faviconデータ再取得中のシート表示用
	
	HiGroupEditor	*groupEditor;
	HiNoteEditor	*noteEditor;
	HiURLEditor		*urlEditor;
	HiHTMLMaker		*htmlMaker;
	NSPopUpButton	*folderButton;	//データフォルダー選択ポップアップボタン
	NSMenuItem		*folderMenu;	//データフォルダー選択メニュー
	
	id				dataFolder;	//データフォルダまでのフルパス名
	NSMutableArray	*folderCollection;	//データフォルダ集
	BOOL			renewAwake;		//起動時にデータフォルダ一覧表のチェックをするかどうかのフラグ
	double			watchSeconds;	//ＬＡＮ上のデータフォルダを確認するまでの最大監視時間
	double			delaySeconds;	//ＬＡＮ上のデータフォルダを確認してからアクセスするまでの遅延時間
	NSString		*defaultBrowser;	//HiURLCenterデフォルトのブラウザ
	NSString		*fileBrowser;	//デフォルトのファイルブラウザ
//-------------------------------v180
	NSString		*fileEditor;	//デフォルトのファイルエディタ
	NSString		*pdfReader;		//デフォルトのPDFリーダ
	NSString		*docEditor;		//デフォルトのワープロ
	NSString		*docsetReader;	//デフォルトのドキュメントセットリーダ
	//---------------------------v210
	NSString		*pictureViewer;
	NSString		*moviePlayer;
	NSString		*soundPlayer;
//-----------------------------------
	
	int				selectExecMax;	//選択して実行時の最大実行項目数
}

//********************
// 初期化等
//********************

- (void)initOffice;
//- (void)initDataSource:(HiURLBoard *)source;

//********************
// アクセッサ
//********************

- (HiURLBoard *)board;
- (float)indentWidth;
- (void)setIndentWidth:(float)indent;
- (BOOL)renewAwake;
- (void)setRenewAwake:(BOOL)inBool;
- (NSString *)defaultBrowser;
- (void)setDefaultBrowser:(NSString *)browser;
- (NSString *)fileBrowser;
- (void)setFileBrowser:(NSString *)browser;
//---------------------------------------v180
- (NSString *)fileEditor;
- (void)setFileEditor:(NSString *)editor;
- (NSString *)pdfReader;
- (void)setPDFReader:(NSString *)reader;
- (NSString *)docEditor;
- (void)setDocEditor:(NSString *)editor;
- (NSString *)docsetReader;
- (void)setDocsetReader:(NSString *)reader;
//---------------------------------------v210
- (NSString *)pictureViewer;
- (void)setPictureViewer:(NSString *)browser;
- (NSString *)moviePlayer;
- (void)setMoviePlayer:(NSString *)player;
- (NSString *)soundPlayer;
- (void)setSoundPlayer:(NSString *)player;
//------------------------------------------
- (int)selectExecMax;
- (void)setSelectExecMax:(int)inMax;
//----------------------v182
- (id)progressIndicator;
//-------------------------

//********************
// アクション
//********************

- (void)actSelectItem:(id)sender;		//一覧表の一行を選択した
- (void)actDoubleClick:(id)sender;		//一覧表がダブルクリックされると呼び出される
- (void)actEditNotes:(id)sender;		//備考欄の変更
- (void)actDelete:(id)sender;			//選択行の削除
- (void)actRestruct:(id)sender;			//一覧表の再構築（データフォルダと同じ順番で表示）
- (void)actRenewal:(id)sender;			//一覧表の再調査（データフォルダと内容が同じにする）
- (void)actChangeFolder:(id)sender;		//ファイル選択パネルによるデータフォルダーの変更（最終的にはchangeFolder:の実行）
- (void)actSelectFolder:(id)sender;		//ポップアップメニューによるデータフォルダの選択（最終的にはchangeFolder:の実行）
- (void)actGetFavicon:(id)sender;		//faviconデータの再取得
- (void)actCollapsAll:(id)sender;		//すべてのグループを閉じる
- (void)actExpandAll:(id)sender;		//すべてのグループを開く
- (void)actSwitchState:(id)sender;		//選択されているグループを開閉する
- (void)actOpenURL:(id)sender;			//選択したURLの実行（ダブルクリック）
- (void)actLaunchBrowser:(id)sender;	//ブラウザボタンをクリックしブラウザを起動
- (void)actCopyFavicon:(id)sender;		//faviconイメージファイルをデスクトップに作成
- (void)actAccessURL:(id)sender;		//情報資源を開く

- (void)openURLWithGroup:(id)groupName
				  sender:(id)sender;	//選択したグループ内のＵＲＬの実行
- (void)openURLWithPath:(id)filePath
				 sender:(id)sender;		//filePathのURLを実行

//****************
//ドラッグ＆ドロップ
//****************

- (int)droppedNewURLItem:(id )urlName
					 url:(id )urlData
			  parentItem:(id )parent
			   dropPoint:(int)index;	//ドロップされたURLデータを作成しドロップ位置に挿入する
- (int)droppedNewURLItem:(id )urlName
					 url:(id )urlData
			  parentItem:(id )parent
			   dropPoint:(int)index
				   watch:(BOOL)watch;	//ドロップされたURLデータを作成しドロップ位置に挿入する
										//watchがYESなら実際にURLにアクセスする
- (BOOL)dragURLDatas:(NSMutableArray *)pathList
			 toGroup:(id )toGroup
			 atIndex:(int)atIndex;		//アプリ内部のドラッグ＆ドロップ処理のすべて

//********************
// ユーティリティメソッド
//********************

//グループリスト関係
- (NSMutableArray *)
	groupListToGroupItem:(id)groupItem;		//groupItemまでのグループリスト（groupItem含む）
- (NSMutableArray *)
	groupListToSelectedRow;					//選択されているアイテム直前までのグループリスト
- (NSMutableArray *)
	groupListIncludeSelfToSelectedRow;		//選択されているアイテムを含むグループリスト
- (NSMutableArray *)
	groupListOfFullPath:(id)itemPath;		//itemPath（フルパス名）のデータフォルダから最後のアイテムまでのグループリスト
- (NSMutableArray *)
	groupListToIndex:(int)index;			//目的のアイテム直前までのグループリスト


//選択パス関係
- (NSMutableArray *)
	purePathListOfItems:(NSArray *)items;	//items行以下(複数)のitemsのパスリスト（ファイル識別子がつく）
- (NSMutableArray *)
	pathListOfItems:(NSArray *)items;		//items行以下(複数)のitemsのパスリスト（ファイル識別子はつかない）
- (id)filePathOfURLItem:(id)item;			//itemを含むデータフォルダからのファイルパス
- (id)folderPathAtSelectedRow;				//現在選択されている行までのディレクトリパスを得る（自身がディレクトリの場合は自身を含めるパス）
- (id)folderPathAtIndex:(int)index;			//index行までのディレクトリパスを得る（自身がディレクトリの場合は自身を含めるパス）
- (id)filePathAtSelectedRow;				//現在選択されている行のファイルパスを得る
- (id)filePathAtIndex:(int)index;			//index行までのファイルパス（自分自身を含める）を得る、ファイルの場合は最後の_は削除
- (id)pureFilePathAtIndex:(int)index;		//index行までのファイルパス（自分自身を含める）を得る、ファイルの場合の最後の_は削除されない
- (id)parentPathAtSelectedRow;				//現在選択されている行直前までのディレクトリパスを得る（自身は含めない）
- (id)parentPathAtIndex:(int)index;			//index行直前までのディレクトリパスを得る（自身は含めない）
- (id)relativePath:(id)fullPath;			//フルパスからデータフォルダからの相対パスを得る

//選択アイテム関係
- (NSMutableArray *)
	itemListAtSelectedRow;					//選択行（複数可）のアイテムリスト
- (id)realItemNameAtSelectedRow;			//生のアイテム名（ファイル名識別子は削除されない）
- (id)realItemNameAtIndex:(int)index;
- (id)titleNameAtSelectedRow;				//グループ名（ルートからのパス名）またはファイル名（ファイル名識別子が削除される）
- (id)titleNameAtIndex:(int)index;			//
- (id)groupNameAtSelectedRow;				//グループ名（親の名前は削除される）
- (id)groupNameAtIndex:(int *)index;		//index行のアイテムの属するグループ名（生のグループ名を返す)
- (id)itemNameAtIndex:(int)index;			//index行の生のアイテム名、グループなら最後のコンポーネント
- (BOOL)isGroupItemAtSelectedRow;			//選択行がグループ名かどうか調べる
- (BOOL)isGroupItemAtIndex:(int)index;		//index行がグループ名かどうか調べる
- (BOOL)isExpandedItemAtSelectedRow;		//選択行が展開されているかどうかを調べる
- (BOOL)isExpandedItemAtIndex:(int)index;	//index行が展開されているかどうか調べる
- (BOOL)isExistFolder:(id )folderPath
				 file:(id )fileName;		//指定のフォルダ内に同じファイル名のものがないかどうかをチェック
- (BOOL)isExistAtSelectedRow:(id )name;		//選択しているフォルダまたはファイルと同じ名前のフォルダまたはファイルがあれば警告し、YESを返す
											//選択しているフォルダが展開していればフォルダ内部のファイルをチェック
- (int)filesInDirectoryAtSelectedRow;		//選択行のディレクトリ内のファイル数
- (BOOL)isItemExpandedAtSelectedRow;		//選択されている行が展開されていればYES
- (BOOL)isWebURLItemAtSelectedRow;			//選択行がURLアイテムかどうかを調べる
- (void)collapseGroupAtSelectedRow;			//選択されている行のグループを閉じる
- (void)expandGroupAtSelectedRow;			//選択されている行のグループを開く

//アイテム作成関係
- (BOOL)createFolderWithNameAtPath:(id )path
							  name:(id )name;	//pathパス上にname名のフォルダを作成する
- (int)createURLDataFileAtPath:(id )path
							 name:(id )name
							  url:(id )url;	//指定のパス内にurlデータを持つファイル名nameのファイルを作成する
- (int)createURLDataFileAtPath:(id )path
						  name:(id )name
						   url:(id )url
						 watch:(BOOL)watch;	//指定のパス内にurlデータを持つファイル名nameのファイルを作成する
- (int)createURLDataFileAtPath:(id )path	//フォルダーパス
						  name:(id )name
						   url:(id )url
						access:(BOOL)access;	//YESならＵＲＬにアクセスする、NOならアクセスしない
- (int)createURLDataFileAtPath:(id )path	//フォルダーパス
						  name:(id )name
						   url:(id )url
						access:(BOOL)access
						 watch:(BOOL)watch;	//YESならＵＲＬにアクセスする、NOならアクセスしない

//アイテム移動
- (int)movePathList:(NSMutableArray *)pathList
			toGroup:(NSMutableArray *)toGroup
			 atIndex:(int)atIndex;			//指定のパスリスト内のアイテムを目的のパス内に移動する
- (int)movePathListSub:(NSMutableArray *)pathList	//移動元のパスリスト
			   toGroup:(NSMutableArray *)toGroup	//移動先のディレクトリ
			   atIndex:(int)moveToIndex				//移動先の挿入位置
			     count:(int)count;
- (int)moveItemToGroup:(NSMutableArray *)toGroup
					atIndex:(int)atIndex
				fromGroup:(NSMutableArray *)fromGroup
					itemName:(id )itemName;	//１個のアイテムを指定の場所に移動する
- (BOOL)isMoveToDown:(id )itemPath
			  folder:(id )folderPath
			 toIndex:(int)toIndex;	//移動が同じグループ内で上から下ならＹＥＳ

//アイテム挿入
- (BOOL)insertEmptyItemInGroup:(NSMutableArray *)groupList
					   atIndex:(int)index
					  itemName:(id )insertItem;	//insertItemをgroupList内のindex番目の位置に挿入する
- (BOOL)insertItemInGroup:(NSMutableArray *)groupList
				  atIndex:(int)index
					 item:(NSMutableArray *)insertItem;	//insertItemをgroupList内のindex番目の位置に挿入する
- (id)insertGroupItemAtGroup:(NSMutableArray *)atGroup
							 atIndex:(int)atIndex
						  insertItem:(NSMutableArray *)insertItem;	//グループをgroupList内のindex番目の位置に挿入する
					  
//アイテム削除関係
- (void)deleteItemWithGroup:(NSMutableArray *)group
					   item:(id )item;
- (void)deleteGroupItemWithGroup:(NSMutableArray *)group
							item:(id )item;	//グループアイテムを削除
- (void)deleteTitleItemWithGroup:(NSMutableArray *)group
						  item:(id )item;	//URLアイテムを削除する
- (BOOL)deleteItemAtSelectedRowWithMode:(BOOL)mode; //選択されているアイテムを１つ削除する、modeが1ならオリジナルファイルも削除する
- (BOOL)deleteFolderAtSelectedRow;	//選択行のフォルダを削除する
- (BOOL)deleteFileAtSelectedRow;	//選択行のファイルを削除する
- (BOOL)deleteOriginalFileAtURL:(NSString *)url;	//URLのオリジナルファイルを削除する
- (int)verifyDeleteItems;	//アイテム削除の確認をする
- (BOOL)trashFile:(NSString *)filePath;		//ファイルをゴミ箱に入れる
- (BOOL)trashFolder:(NSString *)filePath;	//フォルダをゴミ箱に入れる
- (BOOL)trashPath:(NSString *)filePath;		//ファイルまたはフォルダをゴミ箱に入れる

//アイテム関係
- (NSMutableArray *)itemListWithGroupItem:(id)groupItem;	//groupItem内のアイテムリスト（生データ：ファイル識別子あり）
- (void)renewGroupName:(NSMutableArray *)group
		withParentName:(id )parentName;	//挿入したグループ以下のグループ名を変更する
- (BOOL)isSameGroup:(NSArray *)groupA
		   andGroup:(NSArray *)groupB;	//グループの比較
- (int)indexWithGroup:(NSArray *)group
				 item:(id)itemName;	//groupグループ内のitemNameアイテムの位置
- (id)realNameWithPath:(id)path;	//フルパスから生のアイテム名又はグループ名を得る

//URL関係
- (id)urlStringOfItem:(id)item group:(id )group;	//groupグループ内のitemのURLデータ文字列
- (id)urlStringAtSelectedRow;	//選択行のURLデータ文字列
- (id)urlStringAtIndex:(int)index;
- (id)urlOfItem:(id )name;

//ブラウザ関係
- (id)browserAtSelectedRow;

//備考関係
- (id)noteOfItem:(id )name;				//データフォルダ内のnameアイテムの備考文字を得る
- (id)noteAtGroup:(NSMutableArray *)group
				 itemName:(id )name;	//groupフォルダ内のnameアイテムの備考文字列を得る
- (void)replaceNoteAtGroup:(NSMutableArray *)group
					  name:(id )name
					  note:(id )note;	//指定場所の備考文字列を変更する
					  
//表示関係
- (void)renewList;	//一覧表の表示をすべて更新
- (void)renewItemCount;	//一覧表内のアイテム数を表示する
- (void)renewalAccessInfo;	//アクセス情報を更新表示する
- (void)addToolTipsForCompleteTitle;
- (void)resetURLList;
- (id)stringForToolTipAtRow:(int)row
					 column:(int)column;

//データフォルダー関係
- (id)dataFolder;						//現在のデータフォルダ
- (void)setDataFolder:(id)path;			//データフォルダの設定
- (int)maxFolderItems;					//データフォルダーの最大数
- (void)setMaxFolderItems:(int)items;	//データフォルダーの最大数設定
- (void)setFolderCollection:(NSMutableArray *)collection;
- (void)saveFolderCollection;
- (void)setSubmenuInMenu:(id)menu
				  folder:(id )folderPath;	//データフォルダメニューの設定
- (void)renewSubmenuInMenu:(NSMenu *)menu;	//データフォルダメニューの更新
- (void)removeFolderCollection:(NSString *)folderPath;	//データフォルダー集からfolderPathを削除する
- (void)restructFolderCollection:(id )folderPath;	//データフォルダ集の再構築(folderPathを追加）
- (BOOL)checkDuplicateFolderPath:(id )folderPath;	//データフォルダ集の重複をチェック
- (void)modifyFolderCollection;	//フォルダ集のパスをチェックし、無効なパスは削除する
- (BOOL)manageDataFolder;	//起動時データフォルダの選択
- (int)selectProcess;		//データフォルダを選択、デフォルトを使う、アプリ中止を返す
- (id )selectDataFolder;	//データフォルダを選択する（起動時のみ呼ばれる）
- (void)setDefaultFolder;	//デフォルトのデータフォルダを設定あるいは作成する
- (void)renewFolderCollectionMenu:(id )folderPath;	//folderButton用メニュー、folderMenu用サブメニューを更新する
- (void)changeFolder:(id )path;	//データフォルダの変更	
- (BOOL)isFolderExist:(id )path;	//データフォルダの有無
- (void)restructDataFolder:(id )path;	//データフォルダを再構成する
- (void)renewalDataFolder:(id )path;		//データフォルダを再調査する
- (BOOL)isItemExistInDataFolder:(id )itemPath;	//DataFolder内のitemPathフォルダ又はファイルの存在を調べる
- (BOOL)isItemExist:(id)itemPath;	//itemPathフォルダ又はファイルの存在を調べる

//行選択関係
- (void)selectNextRow;	//選択行を現在の選択行の１行下にする
- (BOOL)checkSelectRange;	//グループと同じグループ内のアイテムが同時に選択されていないかどうかをチェック
- (int)selectedFirstRow;	//選択行の最上行
- (NSIndexSet *)reviveLastSelect;	//前回の選択行を選択する
- (void)saveLastSelect;		//現在の選択行を前回の選択行として保存する
- (void)selectTailRow;		//最後尾の行を選択する

//プログレス表示関係
- (void)dispProgressNoteWithTitle:(id )title
					   infomation:(id )infomation
						   folder:(id )folder;
- (void)stopProgressNote;

//その他
- (BOOL)checkLockedFile;	//選択しているファイルがロックされていれば警告し、YESを返す(他のクラスのみで使用)
- (void)reviseForbiddenCharacterInFolder;	//データフォルダ内のフォルダ名、ファイル名の使用禁止キャラクタを_に変更する
- (void)reviseForbiddenCharacterOnFile:(id)fileName;	//ファイル名の中に':'があれば'_'に変更する
- (BOOL)isContainForbiddenCharacter:(id )inspectString;	//文字列にコロン：文字が含まれていないかどうかをチェックする
- (id )stringByReplacingForbiddenCharacter:(id)sourceString;	////半角コロン：とスラッシュ/を全角に変換する
- (id)pathWithGroupList:(NSMutableArray *)groupList;
- (int)rowForItem:(id)item;	//itemアイテムの行番号（アイテムが表示されていなければ-1）
- (void)openGroup:(NSArray *)roots
	andSelectItem:(id)itemName;

- (id)pureItemNameWithPath:(id)itemPath;	//list内を階層的に検索してitemPathのファイル識別子付きアイテム名を得る
- (id)pureItemPathWithGroup:(NSArray *)group
				   itemPath:(id)itemPath
				   itemName:(id *)itemName;

//ネットワークデバイスマウント関係
- (BOOL)mountVolume:(NSString *)volume;
- (BOOL)unmountVolume:(NSString *)volume;
- (void)dispMountNoteWithTitle:(id)title
						volume:(id)volume;
- (void)stopMountNote;

//スタートアップアニメーションを描く
- (void)startupAnimationWithImage:(NSImage *)iconImage		//表示するイメージ
							point:(NSPoint)centerPoint;		//デスクトップに対する表示中心ポイント

//********************
// デリゲートメソッド
//********************

- (BOOL)validateMenuItem:(NSMenuItem*)item;	//ツールメニューのイネーブル設定

//********************
// 実行状況表示関係
//********************

- (void)startProgress:(NSString *)message;
- (void)sheetDidEnd:(NSWindow *)sheet
		 returnCode:(int)returnCode
		contextInfo:(void *)contextInfo;
- (void)stopProgress;

@end
