#import <Cocoa/Cocoa.h>
#import <Carbon/Carbon.h>

#define WINURLHEADER_STRING		@"[InternetShortcut]"
#define WINURLHEADER_LENGTH		18
#define WINURLMARK_STRING		@"URL="
#define MAILTOHEADER_STRING		@"mailto:"
#define MAILTOHEADER_LENGTH		7
#define NOAPPFILEFAVICON_NAME	@"DefaultFileFavicon.png"
#define UNABLEFILEFAVICON_NAME	@"UnableFileFavicon.png"
#define DEFAULTWINFAVICON_NAME	@"DefaultWinFavicon.png"
#define DefaultEncodingCharacter	NSJapaneseEUCStringEncoding
#define	DEFAULTOUTFOLDER_NAME	@"~/Desktop"

#define FilePageHeader	@"file:"
#define MailtoHeader	@"mailto:"
#define HTTPHeader		@"http:"
#define	HTTPSHeader		@"https:"
#define	FTPHeader		@"ftp:"
#define FTPSHeader		@"ftps:"
#define FEEDHeader		@"feed:"
#define AFPHeader		@"afp:"
#define SMBHeader		@"smb:"

#define FileNameLengthMax	80		//タイトル（ファイル名）の最大文字数
#define FaviconSize_Width	16
#define FaviconSize_Height	16


#define Def_TimeoutSeconds	60
#define Key_TimeoutSeconds	@"TimeoutSeconds"

#define Def_FaviconTimeout	10.0	//Favicon取得時のタイムアウト時間

#define kWebLocExtension	@"webloc"
#define kWinUrlExtension	@"url"

//#define kPasswordCover	@"********"
#define kPasswordCover		NSLocalizedString(@"********",@"********")
#define	kDefaultIconData	@"DefaultIcon.data"

#define	Key_CachedFaviconImage	@"CachedFaviconImage"
#define	Key_CachedFaviconPath	@"CachedFaviconPath"

//#define	kTempFilePath		@"/.TempFile.tmp"

@class HiURLOffice;
@class HiCommenter;
//@class HiColorLabel;

//*******************
//その他ユーティリティ
//*******************

void HiCopyCStringToPascal(const char *cString, Str255 pString);

@interface HiWeblocFile : NSObject
{
	id			center;
	HiURLOffice *office;
	HiCommenter	*commenter;
	NSWindow	*mainWindow;
	
	NSString	*lastAddress;		//前回データが読み込まれたＵＲＬ
	NSData		*pageData;
	NSData		*tempData;
	BOOL		connecting;
	BOOL		breakConnection;
	BOOL		timeupConnection;
	BOOL		lastAccess;			//前回アクセスに成功した
	int			lastEncode;			//前回データのエンコード番号（データの読み込みで０クリアされる）
	int			timeoutSeconds;
	NSDictionary	*specialChars;	//特殊文字変換用リスト
	NSMutableArray *cachedFavicon;	//ファビコンのキャッシュ
	BOOL		intelMac;
	NSImage		*iTunesIconImage;
}

- (void)dealloc;

//パブリック
//- (BOOL)isExistURLDataFile:(NSString *)filePath;
- (BOOL)isURLDataFile:(NSString *)filePath;
- (BOOL)isHTMLFile:(NSString *)filePath;
//-------------------------------------v180(Additional)
- (BOOL)isDocumentFile:(NSString *)inURL;
- (BOOL)isPDFFile:(NSString *)inURL;
- (BOOL)isTXTFile:(NSString *)inURL;
- (BOOL)isRTFFile:(NSString *)inURL;
- (BOOL)isDOCFile:(NSString *)inURL;
- (BOOL)isDOCSETFile:(NSString *)inURL;
//----------------------------------------v210
- (BOOL)isMultimediaFile:(NSString *)filePath;
- (BOOL)isMovieFile:(NSString *)filePath;
- (BOOL)isPictureFile:(NSString *)filePath;
- (BOOL)isSoundFile:(NSString *)filePath;

- (BOOL)isMOVFile:(NSString *)filePath;
- (BOOL)isM4VFile:(NSString *)filePath;
- (BOOL)isAVIFile:(NSString *)filePath;
- (BOOL)isMP4File:(NSString *)filePath;
- (BOOL)isFLVFile:(NSString *)filePath;
- (BOOL)isASFFile:(NSString *)filePath;
- (BOOL)isWMVFile:(NSString *)filePath;
- (BOOL)isRMVBFile:(NSString *)filePath;
- (BOOL)is3GPFile:(NSString *)filePath;
- (BOOL)isMKVFile:(NSString *)filePath;
- (BOOL)isMPGFile:(NSString *)filePath;
- (BOOL)isOGMFile:(NSString *)filePath;
- (BOOL)isRMFile:(NSString *)filePath;

- (BOOL)isTIFFile:(NSString *)filePath;
- (BOOL)isJPGFile:(NSString *)filePath;
- (BOOL)isPNGFile:(NSString *)filePath;
- (BOOL)isGIFFile:(NSString *)filePath;

- (BOOL)isAIFFile:(NSString *)filePath;
- (BOOL)isM4AFile:(NSString *)filePath;
- (BOOL)isMP3File:(NSString *)filePath;
- (BOOL)isMIDFile:(NSString *)filePath;
- (BOOL)isWAVFile:(NSString *)filePath;

- (NSString *)defaultPictureBrowser:(NSString *)url;
- (NSString *)defaultMoviePlayer:(NSString *)url;
- (NSString *)defaultSoundPlayer:(NSString *)url;

- (NSImage *)defaultPictureFavicon;
- (NSImage *)defaultMovieFavicon;
- (NSImage *)defaultSoundFavicon;
//----------------------------------------v220
- (NSImage *)appFaviconWithPath:(NSString *)path;	//pathで指定のアプリアイコンを得る
- (BOOL)isAPPFile:(NSString *)filePath;
- (BOOL)haveExtensionFile:(NSString *)filePath;
//-------------------------------------------

- (NSString *)urlInURLDataFile:(NSString *)filePath;
- (int)timesInURLDataFile:(NSString *)filePath;
- (NSString *)dateInURLDataFile:(NSString *)filePath;
- (NSString *)browserInURLDataFile:(NSString *)filePath;

- (BOOL)setTimesInURLDataFile:(NSString *)filePath times:(int)times;
- (void)setDateInURLDataFile:(NSString *)filePath;
- (BOOL)setNoteInURLDataFile:(NSString *)filePath note:(NSString *)inNote;
- (BOOL)setUrlInURLDataFile:(NSString *)filePath url:(NSString *)inUrl;
- (BOOL)setBrowserInURLDataFile:(NSString *)filePath browser:(NSString *)browser;

//***********************
//Weblocファイル関係メソッド
//***********************

- (BOOL)createWeblocFile:(NSString *)filePath;	//インターネットショートカットファイルを作成する
- (BOOL)createWeblocResource:(NSString *)path;	//インターネットショートカットファイルのリソースを作成する
- (NSString *)urlInWeblocFile:(NSString *)filePath;	//インターネットショートカットファイルのＵＲＬデータを得る
- (NSString *)noteInWeblocFile:(NSString *)filePath;
- (int)timesInWeblocFile:(NSString *)filePath;
- (BOOL)setUrlInWeblocFile:(NSString *)filePath url:(NSString *)inUrl;	//インターネットショートカットファイルにＵＲＬを書き込む
- (BOOL)setNoteInWeblocFile:(NSString *)filePath note:(NSString *)inNote;

- (NSString *)dateInWeblocFile:(NSString *)filePath;	//インターネットショートカットファイルのアクセス日時を得る
- (NSString *)setDateInWeblocFile:(NSString *)filePath;		//インターネットショートカットファイルに現在のDateを書き込む

- (BOOL)setTimesInWeblocFile:(NSString *)filePath times:(int)times;
- (BOOL)setGroupName:(NSString *)groupName atPath:(NSString *)filePath;
- (BOOL)setURLName:(NSString *)urlName atPath:(NSString *)filePath;
- (BOOL)isWeblocFile:(NSString *)filePath;
- (BOOL)isWinurlFile:(NSString *)filePath;
- (BOOL)haveWeblocResource:(NSString *)path;
- (BOOL)createWinurlFile:(NSString *)filePath;
- (NSString *)urlInWinurlFile:(NSString *)filePath;
- (BOOL)setUrlInWinurlFile:(NSString *)filePath url:(NSString *)inUrl;
- (NSString *)browserInWeblocFile:(NSString *)filePath;
- (BOOL)setBrowserInWeblocFile:(NSString *)filePath browser:(NSString *)browser;
- (NSColor *)colorInWeblocFile:(NSString *)file;
- (BOOL)setColorInWeblocFile:(NSString *)file color:(NSColor *)color;

//****************
//favicon関係メソッド
//****************

- (NSData *)faviconDataInWebPage:(NSString *)address;	//ＷＥＢページからfaviconデータを得る
- (BOOL)haveFaviconInWeblocFile:(NSString *)filepath;	//faviconデータを持っているかどうかを調べる
- (NSImage *)faviconInWeblocFile:(NSString *)filePath;	//ファイルに保存してあるfavicon(サイズは16x16)
- (NSImage *)cachedFaviconWithPath:(NSString *)path;	//メモリーにfaviconイメージがあればイメージを返す、なければnilを返す
- (void)setCachedFaviconWithPath:(NSString *)path
						   image:(NSImage *)image;		//メモリーにfaviconイメージを保存する
- (void)uncacheFaviconWithPath:(NSString *)path;		//メモリーに保存してあるfaviconイメージを削除する
- (BOOL)resetFaviconInWeblocFile:(NSString *)filePath;	//faviリソースを削除する
- (BOOL)setFaviconInWeblocFile:(NSString *)filePath
					   favicon:(NSData *)faviconData;	//ファイルアイコンをfaviconにする
- (BOOL)setFaviconInWeblocFile:(NSString *)filePath
						 image:(NSImage *)image;
- (NSImage *)defaultFavicon:(NSString *)path;
- (NSString *)defaultApplication:(NSString *)path;
- (NSImage *)unableProtocolFavicon;
- (NSImage *)noApplicationFavicon;
- (NSImage *)defaultWinurlFavicon;
- (NSImage *)defaultMailerFavicon;
- (NSImage *)defaultHTTPFavicon;
- (NSImage *)defaultHTTPSFavicon;
- (NSImage *)defaultFTPFavicon;
- (NSImage *)defaultFTPSFavicon;
- (NSImage *)defaultFilerFavicon;
//------------------------------------v180
- (NSString *)defaultEditor:(NSString *)url;
- (NSString *)defaultEditorWithExtension:(CFStringRef)inExtension;
//- (NSString *)defaultDocsetReader:(NSString *)url;
- (NSImage *)defaultRTFFavicon;
- (NSImage *)defaultTXTFavicon;
- (NSImage *)defaultPDFFavicon;
- (NSImage *)defaultDOCFavicon;
- (NSImage *)defaultDOCSETFavicon;
//----------------------------------------
- (NSImage *)defaultFEEDFavicon;
- (NSImage *)defaultAFPFavicon;
- (NSImage *)defaultSMBFavicon;
- (NSImage *)defaultFaviconWithProtocol:(CFStringRef)protocol;
- (BOOL)isSupportedApp:(NSString *)application
		  withProtocol:(CFStringRef)protocol;		//アプリケーションapplicationがプロトコルprotocolに対応しているかどうかを調べる
- (BOOL)isSupportedApp:(NSString *)application
			  withFile:(NSString *)filePath;
- (NSImage *)defaultFaviconWithApplication:(NSString *)appPath;
- (NSString *)defaultApplicationWithProtocol:(CFStringRef)protocol;
- (NSString *)faviconNameWithData:(NSData *)data;
- (NSString *)faviconNameWithDataSub:(NSData *)data
							encode:(NSStringEncoding)encode;	//dataからfaviconファイル名を探す
- (NSImage *)fixImage16x16:(NSImage *)orgImage;		//イメージの大きさを16x16ドットにする
- (void)setiTunesIconImage;
- (NSImage *)iTunesIconImage;


//*****************
//URL関係ユーティリティ
//*****************

- (NSString *)titleNameInWebPage:(NSString *)address;		//WEBページのタイトル名を取得
- (NSString *)changeFEEDtoHTMLAddress:(NSString *)address;
- (NSString *)titleNameWithData:(NSData *)data
						  encode:(NSStringEncoding)encode;	//dataからタイトル名を探す,特種文字を変換する
- (NSMutableDictionary *)createSpecialChars;	//特殊文字変換用の辞書を作成する
- (NSString *)convertSpecialCharacters:(NSString *)title;	//titleに含まれる&nbsp;等の特殊文字を通常の文字に変換する
- (NSString *)specialCharactorWithCode:(NSString *)codeStr;
- (int)codeWithString:(NSString *)codeString;
- (BOOL)isProtocolAddress:(NSString *)address;
- (BOOL)isWebURLAddress:(NSString *)address;
- (BOOL)isFileURLAddress:(NSString *)address;
- (BOOL)isMailtoAddress:(NSString *)address;
- (BOOL)isHTTPAddress:(NSString *)address;
- (BOOL)isHTTPSAddress:(NSString *)address;
- (BOOL)isFTPAddress:(NSString *)address;
- (BOOL)isFTPSAddress:(NSString *)address;
- (BOOL)isFEEDAddress:(NSString *)address;
- (BOOL)isWinurlData:(NSString *)url;
- (BOOL)isAFPAddress:(NSString *)address;
- (BOOL)isSMBAddress:(NSString *)address;
- (NSString *)passwordInURL:(NSString *)urlStr;
- (NSString *)coverPasswordInURL:(NSString *)urlStr;
- (NSString *)uncoverPasswordInURL:(NSString *)urlStr password:(NSString *)passStr;
- (NSString *)pureDataInURLDataFile:(NSString *)filePath;
- (NSString *)urlDataWithPureURLData:(NSString *)pureUrl;
- (int)encodeNumberOfData:(NSData *)data;	//ページデータからエンコード番号を得る	
- (BOOL)isEncodeNameEUC:(NSString *)encodeName;
- (BOOL)isEncodeNameSJIS:(NSString *)encodeName;
- (BOOL)isEncodeNameUTF:(NSString *)encodeName;
- (NSString *)checkEncodeName:(NSString *)encodeName;
- (NSString *)encodeNameSub:(NSData *)data;
- (NSString *)encodeNameWithData:(NSData *)data
						 keyword:(NSString *)keyword
						encoding:(NSStringEncoding)encode;
- (NSStringEncoding)encodingWithData:(NSData *)data;
- (NSString *)disposeStringForSearch:(const char *)data
					    length:(int)length
					  encoding:(NSStringEncoding)encode;	//dataから長さがlengthの検索用文字列を得る
- (int)searchData:(NSData *)data
		fromIndex:(int)index
		  keyword:(NSString *)keyword
		 encoding:(NSStringEncoding)encode;				//dataのindex位置からkeywordを検索する
- (int)commentLengthOfData:(NSData *)data
				 fromIndex:(int)index
				  encoding:(NSStringEncoding)encode;	//先頭文字が"<!--"なら"-->"までのバイト数を数える
- (int)searchCommentEnd:(NSData *)data
		fromIndex:(int)index
		 encoding:(NSStringEncoding)encode;	//dataのindex位置から"-->"を検索する
- (int)searchBackwardData:(NSData *)data
				fromIndex:(int)index
				  keyword:(NSString *)keyword
				 encoding:(NSStringEncoding)encode;
- (NSData *)dataWithWebPageAddress:(NSString *)address;	//アドレスからデータを読み込む
- (void)connectionThread:(id)address;
- (void)animationThread:(id)sender;	//インターネットアクセスのアニメーションを行う
- (BOOL)isInternalServerError:(NSData *)data;			//dataがInternal Server Errorかどうかを調べる


//*******************
//ファイル関係ユーティリティ
//*******************

- (NSArray *)pathsFromPathList:(NSArray *)pathList;		//pathListのファイル名識別子を削除したものを得る
- (BOOL)checkDuplicatePathList:(NSArray *)pathList
					  destPath:(NSString *)destPath;	//destPathに同じ名前のファイルあるいはフォルダがないかどうかチェックする
- (NSMutableArray *)movePathList:(NSMutableArray *)pathList
						destPath:(NSString *)destPath;	//パスリストpathListのファイルすべてをdestFolderへ移動する
- (NSMutableArray *)copyPathList:(NSMutableArray *)pathList
						destPath:(NSString *)destPath;	//パスリストpathListのファイルすべてをdestFolderへコピーする
- (NSNumber *)typeWithNumber:(unsigned long)number;		//インテルなら４文字をリバースする


//*******************
//アクセッサ
//*******************

- (int)timeoutSeconds;
- (void)setTimeoutSeconds:(int)seconds;
- (BOOL)connecting;
- (void)setConnecting:(BOOL)inBool;

@end
